import os


class SettingsReader():

    def __init__(self, **kwargs):
        """
        kwargs is a mapping, of setting_name and its options:
        env_name, var_type, default:

         * setting_name is the name for the setting in the returned dict
         * env_name is the name of the environment variable.
         * var_type can be int, str, bool
         * default is optional, and will be returned if the environment
           variable is undefined. An error will be raise if it is undefined and
           there is no default.
        """

        for setting_name, setting_opts in kwargs.items():
            var_name = setting_opts[0]
            setting_name = setting_name
            var_type = setting_opts[1]

            if var_name not in os.environ:
                if len(setting_opts) >= 3:
                    setattr(self, setting_name, setting_opts[2])
                    continue

                raise ValueError(
                    "Environment variable {} not set.".format(var_name)
                )

            var = os.environ[var_name]

            if var_type == str:
                setattr(self, setting_name, var)
            elif var_type == int:
                setattr(self, setting_name, int(var))
            elif var_type == bool:
                setattr(self, setting_name, var.lower()
                        in ["true", "yes", "on"])
